==> babel-timing-0.5.0.tgz: package/src/standalone/index.js <==
const fs = require('fs');
const path = require('path');
const babel = require('@babel/core');
const multimatch = require('multimatch');
const flatten = require('reduce-flatten');
const getImports = require('./getImports');
const {globPatternsToPaths, onlyUnique} = require('../utils');
const Timer = require('../Timer');
const render = require('../render');

async function babelTiming(
  filePatterns = [],
  {
    babelConfig,
    followImports = false,
    include = ['**'],
    exclude = ['**/node_modules/**'],
    resolveMainFields = ['browser', 'module', 'main'],
    expandPackages = false,
    output,
    outputPath,
    paginationSize,
    verbose = false,
  } = {}
) {
  let files = globPatternsToPaths(filePatterns);

  // Follow and recursively resolve all relative imports
  if (followImports) {
    let importedFiles = await Promise.all(
      files.map(file =>
        getImports(file, {
          babelConfig,
          resolveMainFields,
          include,
          exclude,
          verbose,
        })
      )
    );

    importedFiles = importedFiles.reduce(flatten, []).filter(onlyUnique);
    files = importedFiles;
  }

  // All file paths absolute
  files = files.map(file => path.resolve(file));

  if (Array.isArray(include)) {
    files = multimatch(files, include);
  }

  if (Array.isArray(exclude)) {
    const negatedExclude = exclude.map(pattern => `!${pattern}`);
    files = multimatch(files, ['**', ...negatedExclude]);
  }

  let results = files.map(file => {
    const timer = new Timer(file);

    /*
     * Transform all gathered files one by one and collect
     * transform meta data using `wrapPluginVisitorMethod`
     * https://babeljs.io/docs/en/options#configfile
     */
    babel.transformSync(fs.readFileSync(file).toString(), {
      filename: file,
      configFile: babelConfig ? path.join(process.cwd(), babelConfig) : false,
      minified: true,
      compact: true,
      wrapPluginVisitorMethod: timer.wrapPluginVisitorMethod,
    });

    return timer.getResults();
  });

  return render(results, {expandPackages, output, outputPath, paginationSize});
}

module.exports = babelTiming;

==> babel-timing-0.8.0.tgz: package/src/standalone/index.js <==
const fs = require('fs');
const path = require('path');
const babel = require('@babel/core');
const multimatch = require('multimatch');
const flatten = require('reduce-flatten');
const getImports = require('./getImports');
const {globPatternsToPaths, onlyUnique} = require('../utils');
const Timer = require('../Timer');
const render = require('../render');

async function babelTiming(
  filePatterns = [],
  {
    babelConfig,
    followImports = false,
    include = ['**'],
    exclude = ['**/node_modules/**'],
    resolveMainFields = ['browser', 'module', 'main'],
    resolveExtensions = ['.js', '.jsx', '.mjs', '.ts'],
    expandPackages = false,
    output,
    outputPath,
    aggregateBy,
    paginationSize,
  } = {}
) {
  let files = globPatternsToPaths(filePatterns);

  // Follow and recursively resolve all relative imports
  if (followImports) {
    let importedFiles = await Promise.all(
      files.map(file =>
        getImports(file, {
          babelConfig,
          resolveMainFields,
          resolveExtensions,
          include,
          exclude,
        })
      )
    );

    importedFiles = importedFiles.reduce(flatten, []).filter(onlyUnique);
    files = importedFiles;
  }

  // All file paths absolute
  files = files.map(file => path.resolve(file));

  if (Array.isArray(include)) {
    files = multimatch(files, include);
  }

  if (Array.isArray(exclude)) {
    const negatedExclude = exclude.map(pattern => `!${pattern}`);
    files = multimatch(files, ['**', ...negatedExclude]);
  }

  let results = files.map(file => {
    const timer = new Timer(file);

    /*
     * Transform all gathered files one by one and collect
     * transform meta data using `wrapPluginVisitorMethod`
     * https://babeljs.io/docs/en/options#configfile
     */
    babel.transformSync(fs.readFileSync(file).toString(), {
      filename: file,
      configFile: babelConfig ? path.join(process.cwd(), babelConfig) : false,
      minified: true,
      compact: true,
      wrapPluginVisitorMethod: timer.wrapPluginVisitorMethod,
    });

    return timer.getResults();
  });

  return render(results, {
    expandPackages,
    output,
    outputPath,
    aggregateBy,
    paginationSize,
  });
}

module.exports = babelTiming;
